@@ -7,6 +7,7 @@
 """
 Base classes for all gridders.
 """
+import warnings
 from abc import ABCMeta, abstractmethod
 
 import pandas as pd
@@ -14,12 +15,13 @@ from sklearn.base import BaseEstimator
 from sklearn.model_selection import BaseCrossValidator
 
 from ..coordinates import grid_coordinates, profile_coordinates, scatter_points
+from ..utils import (
+    check_meshgrid,
+    get_ndim_horizontal_coords,
+    make_xarray_grid,
+    meshgrid_from_1d,
+)
 from .utils import check_data, check_data_names, score_estimator
-from ..utils import make_xarray_grid
-
-
-# Pylint doesn't like X, y scikit-learn argument names.
-# pylint: disable=invalid-name,unused-argument
 
 
 class BaseBlockCrossValidator(BaseCrossValidator, metaclass=ABCMeta):
@@ -52,7 +54,7 @@ class BaseBlockCrossValidator(BaseCrossValidator, metaclass=ABCMeta):
         self.shape = shape
         self.n_splits = n_splits
 
-    def split(self, X, y=None, groups=None):
+    def split(self, X, y=None, groups=None):  # noqa: N803
         """
         Generate indices to split data into training and test set.
 
@@ -83,7 +85,7 @@ class BaseBlockCrossValidator(BaseCrossValidator, metaclass=ABCMeta):
         for train, test in super().split(X, y, groups):
             yield train, test
 
-    def get_n_splits(self, X=None, y=None, groups=None):
+    def get_n_splits(self, X=None, y=None, groups=None):  # noqa: U100,N803
         """
         Returns the number of splitting iterations in the cross-validator
 
@@ -104,7 +106,7 @@ class BaseBlockCrossValidator(BaseCrossValidator, metaclass=ABCMeta):
         return self.n_splits
 
     @abstractmethod
-    def _iter_test_indices(self, X=None, y=None, groups=None):
+    def _iter_test_indices(self, X=None, y=None, groups=None):  # noqa: U100,N803
         """
         Generates integer indices corresponding to test sets.
 
@@ -130,9 +132,6 @@ class BaseBlockCrossValidator(BaseCrossValidator, metaclass=ABCMeta):
         """
 
 
-# pylint: enable=invalid-name,unused-argument
-
-
 class BaseGridder(BaseEstimator):
     """
     Base class for gridders.
@@ -184,7 +183,7 @@ class BaseGridder(BaseEstimator):
     ...         check_is_fitted(self, ['mean_'])
     ...         return np.ones_like(coordinates[0])*self.mean_
     >>> # Try it on some synthetic data
-    >>> synthetic = vd.datasets.CheckerBoard(region=(0, 5, -10, 8))
+    >>> synthetic = vd.synthetic.CheckerBoard(region=(0, 5, -10, 8))
     >>> data = synthetic.scatter()
     >>> print('{:.4f}'.format(data.scalars.mean()))
     -32.2182
@@ -223,7 +222,7 @@ class BaseGridder(BaseEstimator):
         ("east_component", "north_component", "vertical_component"),
     ]
 
-    def predict(self, coordinates):
+    def predict(self, coordinates):  # noqa: U100
         """
         Predict data on the given coordinate values. NOT IMPLEMENTED.
 
@@ -243,7 +242,7 @@ class BaseGridder(BaseEstimator):
         """
         raise NotImplementedError()
 
-    def fit(self, coordinates, data, weights=None):
+    def fit(self, coordinates, data, weights=None):  # noqa: U100
         """
         Fit the gridder to observed data. NOT IMPLEMENTED.
 
@@ -271,7 +270,7 @@ class BaseGridder(BaseEstimator):
         """
         raise NotImplementedError()
 
-    def filter(self, coordinates, data, weights=None):
+    def filter(self, coordinates, data, weights=None):  # noqa: A003
         """
         Filter the data through the gridder and produce residuals.
 
@@ -324,6 +323,14 @@ class BaseGridder(BaseEstimator):
         predicted values and the given data values. A maximum score of 1 means
         a perfect fit. The score can be negative.
 
+        .. warning::
+
+            The default scoring will change from R² to negative root mean
+            squared error (RMSE) in Verde 2.0.0. This may change model
+            selection results slightly. The negative version will be used to
+            maintain the behaviour of larger scores being better, which is more
+            compatible with current model selection code.
+
         If the data has more than 1 component, the scores of each component
         will be averaged.
 
@@ -349,6 +356,12 @@ class BaseGridder(BaseEstimator):
             The R^2 score
 
         """
+        warnings.warn(
+            "The default scoring will change from R² to negative root mean "
+            "squared error (RMSE) in Verde 2.0.0. "
+            "This may change model selection results slightly.",
+            FutureWarning,
+        )
         return score_estimator("r2", self, coordinates, data, weights=weights)
 
     def grid(
@@ -359,19 +372,24 @@ class BaseGridder(BaseEstimator):
         dims=None,
         data_names=None,
         projection=None,
-        **kwargs
-    ):  # pylint: disable=too-many-locals
+        coordinates=None,
+        **kwargs,
+    ):
         """
         Interpolate the data onto a regular grid.
 
-        The grid can be specified by either the number of points in each
-        dimension (the *shape*) or by the grid node spacing. See
-        :func:`verde.grid_coordinates` for details. Other arguments for
-        :func:`verde.grid_coordinates` can be passed as extra keyword arguments
-        (``kwargs``) to this method.
+        The grid can be specified by two methods:
 
-        If the interpolator collected the input data region, then it will be
-        used if ``region=None``. Otherwise, you must specify the grid region.
+        - Pass the actual *coordinates* of the grid points, as generated by
+          :func:`verde.grid_coordinates` or from an existing
+          :class:`xarray.Dataset` grid.
+        - Let the method define a new grid by either passing the number of
+          points in each dimension (the *shape*) or by the grid node *spacing*.
+          If the interpolator collected the input data region, then it will be
+          used if ``region=None``. Otherwise, you must specify the grid region.
+          See :func:`verde.grid_coordinates` for details. Other arguments for
+          :func:`verde.grid_coordinates` can be passed as extra keyword
+          arguments (``kwargs``) to this method.
 
         Use the *dims* and *data_names* arguments to set custom names for the
         dimensions and the data field(s) in the output :class:`xarray.Dataset`.
@@ -381,12 +399,15 @@ class BaseGridder(BaseEstimator):
         ----------
         region : list = [W, E, S, N]
             The west, east, south, and north boundaries of a given region.
+            Use only if ``coordinates`` is None.
         shape : tuple = (n_north, n_east) or None
             The number of points in the South-North and West-East directions,
             respectively.
+            Use only if ``coordinates`` is None.
         spacing : tuple = (s_north, s_east) or None
             The grid spacing in the South-North and West-East directions,
             respectively.
+            Use only if ``coordinates`` is None.
         dims : list or None
             The names of the northing and easting data dimensions,
             respectively, in the output grid. Default is determined from the
@@ -408,6 +429,13 @@ class BaseGridder(BaseEstimator):
             will be used to project the generated grid coordinates before
             passing them into ``predict``. For example, you can use this to
             generate a geographic grid from a Cartesian gridder.
+        coordinates : tuple of arrays
+            Tuple of arrays containing the coordinates of the grid in the
+            following order: (easting, northing, vertical, ...).
+            The easting and northing arrays could be 1d or 2d arrays, if
+            they are 2d they must be part of a meshgrid.
+            If coordinates are passed, ``region``, ``shape``, and ``spacing``
+            are ignored.
 
         Returns
         -------
@@ -420,16 +448,48 @@ class BaseGridder(BaseEstimator):
         verde.grid_coordinates : Generate the coordinate values for the grid.
 
         """
-        dims = self._get_dims(dims)
-        region = get_instance_region(self, region)
-        coordinates = grid_coordinates(region, shape=shape, spacing=spacing, **kwargs)
+        if coordinates is not None and (spacing is not None or shape is not None):
+            raise ValueError(
+                "Both coordinates and spacing or shape were provided. "
+                + "Please pass only coordinates or either the spacing or the shape."
+            )
+        if coordinates is not None and region is not None:
+            raise ValueError(
+                "Both coordinates and region were provided. "
+                + "Please pass region only if spacing or shape is specified."
+            )
+        # Raise deprecation warning for the region, shape and spacing arguments
+        if spacing is not None or shape is not None or region is not None:
+            warnings.warn(
+                "The 'spacing', 'shape' and 'region' arguments will be removed "
+                + "in Verde v2.0.0. "
+                + "Please use the 'verde.grid_coordinates' function to define "
+                + "grid coordinates and pass them as the 'coordinates' argument.",
+                FutureWarning,
+            )
+        # Get grid coordinates from coordinates parameter
+        if coordinates is not None:
+            ndim = get_ndim_horizontal_coords(*coordinates[:2])
+            if ndim == 1:
+                # Build a meshgrid if easting and northing are 1d
+                coordinates = meshgrid_from_1d(coordinates)
+            else:
+                check_meshgrid(coordinates)
+        # Build the grid coordinates through vd.grid_coordinates
+        else:
+            region = get_instance_region(self, region)
+            coordinates = grid_coordinates(
+                region, shape=shape, spacing=spacing, **kwargs
+            )
+        # Predict on the grid points (project the coordinates if needed)
         if projection is None:
             data = check_data(self.predict(coordinates))
         else:
             data = check_data(
                 self.predict(project_coordinates(coordinates, projection))
             )
-        # Get names for data and any extra coordinates
+        # Get names for dims, data and any extra coordinates
+        dims = self._get_dims(dims)
         data_names = self._get_data_names(data, data_names)
         extra_coords_names = self._get_extra_coords_names(coordinates)
         # Create xarray.Dataset
@@ -455,7 +515,7 @@ class BaseGridder(BaseEstimator):
         dims=None,
         data_names=None,
         projection=None,
-        **kwargs
+        **kwargs,
     ):
         """
         Interpolate values onto a random scatter of points.
@@ -534,7 +594,7 @@ class BaseGridder(BaseEstimator):
         dims=None,
         data_names=None,
         projection=None,
-        **kwargs
+        **kwargs,
     ):
         """
         Interpolate data along a profile between two points.
@@ -760,5 +820,5 @@ def get_instance_region(instance, region):
     if region is None:
         if not hasattr(instance, "region_"):
             raise ValueError("No default region found. Argument must be supplied.")
-        region = getattr(instance, "region_")
+        region = instance.region_
     return region
