@@ -13,10 +13,10 @@ import warnings
 import numpy as np
 from sklearn.utils.validation import check_is_fitted
 
-from .base import n_1d_arrays, BaseGridder, check_fit_input, least_squares
+from .base import BaseGridder, check_fit_input, least_squares, n_1d_arrays
 from .coordinates import get_region
-from .utils import dispatch, parse_engine
 from .model_selection import cross_val_score
+from .utils import dispatch, parse_engine
 
 try:
     import numba
@@ -509,11 +509,11 @@ def warn_weighted_exact_solution(spline, weights):
 
 def greens_func(east, north, mindist):
     "Calculate the Green's function for the Bi-Harmonic Spline"
-    distance = np.sqrt(east ** 2 + north ** 2)
+    distance = np.sqrt(east**2 + north**2)
     # The mindist factor helps avoid singular matrices when the force and
     # computation point are too close
     distance += mindist
-    return (distance ** 2) * (np.log(distance) - 1)
+    return (distance**2) * (np.log(distance) - 1)
 
 
 def predict_numpy(east, north, force_east, force_north, mindist, forces, result):
@@ -540,7 +540,7 @@ def jacobian_numpy(east, north, force_east, force_north, mindist, jac):
 @jit(nopython=True, fastmath=True, parallel=True)
 def predict_numba(east, north, force_east, force_north, mindist, forces, result):
     "Calculate the predicted data using numba to speed things up."
-    for i in numba.prange(east.size):  # pylint: disable=not-an-iterable
+    for i in numba.prange(east.size):
         result[i] = 0
         for j in range(forces.size):
             green = GREENS_FUNC_JIT(
@@ -553,7 +553,7 @@ def predict_numba(east, north, force_east, force_north, mindist, forces, result)
 @jit(nopython=True, fastmath=True, parallel=True)
 def jacobian_numba(east, north, force_east, force_north, mindist, jac):
     "Calculate the Jacobian matrix using numba to speed things up."
-    for i in numba.prange(east.size):  # pylint: disable=not-an-iterable
+    for i in numba.prange(east.size):
         for j in range(force_east.size):
             jac[i, j] = GREENS_FUNC_JIT(
                 east[i] - force_east[j], north[i] - force_north[j], mindist
