@@ -4,21 +4,22 @@
 #
 # This code is part of the Fatiando a Terra project (https://www.fatiando.org)
 #
-# pylint: disable=unused-argument,too-many-locals,protected-access
 """
 Test the base classes and their utility functions.
 """
+import warnings
+
 import numpy as np
 import numpy.testing as npt
 import pytest
 
-from ..base.least_squares import least_squares
-from ..base.utils import check_fit_input, check_coordinates
 from ..base.base_classes import (
-    BaseGridder,
     BaseBlockCrossValidator,
+    BaseGridder,
     get_instance_region,
 )
+from ..base.least_squares import least_squares
+from ..base.utils import check_coordinates, check_fit_input
 from ..coordinates import grid_coordinates, scatter_points
 
 
@@ -95,7 +96,7 @@ class PolyGridder(BaseGridder):
         super().__init__()
         self.degree = degree
 
-    def fit(self, coordinates, data, weights=None):
+    def fit(self, coordinates, data, weights=None):  # noqa: U100
         "Fit an easting polynomial"
         ndata = data.size
         nparams = self.degree + 1
@@ -134,16 +135,28 @@ def test_basegridder():
         # A region should be given because it hasn't been assigned
         grd.grid()
 
-    coordinates_true = grid_coordinates(region, shape)
-    data_true = angular * coordinates_true[0] + linear
-    grid = grd.grid(region, shape)
-    prof = grd.profile((0, -10), (10, -10), 30)
-
     npt.assert_allclose(grd.coefs_, [linear, angular])
-    npt.assert_allclose(grid.scalars.values, data_true)
-    npt.assert_allclose(grid.easting.values, coordinates_true[0][0, :])
-    npt.assert_allclose(grid.northing.values, coordinates_true[1][:, 0])
-    npt.assert_allclose(grd.scatter(region, 1000, random_state=0).scalars, data)
+
+    # Check predictions by comparing against expected values
+    coordinates_true = grid_coordinates(region, shape=shape)
+    data_true = angular * coordinates_true[0] + linear
+    # Grid passing region and shape
+    grids = []
+    grids.append(grd.grid(region=region, shape=shape))
+    # Grid passing grid coordinates
+    grids.append(grd.grid(coordinates=coordinates_true))
+    # Grid passing grid coordinates as 1d arrays
+    grids.append(grd.grid(coordinates=tuple(np.unique(c) for c in coordinates_true)))
+    # Grid on profile
+    prof = grd.profile((0, -10), (10, -10), 30)
+    # Grid on scatter
+    scat = grd.scatter(region=region, size=1000, random_state=0)
+
+    for grid in grids:
+        npt.assert_allclose(grid.scalars.values, data_true)
+        npt.assert_allclose(grid.easting.values, coordinates_true[0][0, :])
+        npt.assert_allclose(grid.northing.values, coordinates_true[1][:, 0])
+    npt.assert_allclose(scat.scalars, data)
     npt.assert_allclose(
         prof.scalars,
         angular * coordinates_true[0][0, :] + linear,
@@ -163,7 +176,7 @@ def test_basegridder_data_names():
     coordinates = scatter_points(region, 1000, random_state=0)
     data = angular * coordinates[0] + linear
     grd = PolyGridder().fit(coordinates, data)
-    grid = grd.grid(region, shape)
+    grid = grd.grid(region=region, shape=shape)
     prof = grd.profile((0, -10), (10, -10), 30)
     # Check if default name for data_names was applied correctly
     assert "scalars" in grid
@@ -205,7 +218,7 @@ def test_basegridder_projection():
     npt.assert_allclose(scat.northing, coordinates[1])
 
     # Check the grid
-    grid = grd.grid(region, shape, projection=proj)
+    grid = grd.grid(region=region, shape=shape, projection=proj)
     npt.assert_allclose(grid.scalars.values, data_true)
     npt.assert_allclose(grid.easting.values, coordinates_true[0][0, :])
     npt.assert_allclose(grid.northing.values, coordinates_true[1][:, 0])
@@ -318,7 +331,7 @@ def test_basegridder_projection_multiple_coordinates():
     npt.assert_allclose(grd.coefs_, [linear, angular / 2])
 
     # The actual values for a grid
-    coordinates_true = grid_coordinates(region, shape, extra_coords=(13, 17))
+    coordinates_true = grid_coordinates(region, shape=shape, extra_coords=(13, 17))
     data_true = angular * coordinates_true[0] + linear
 
     # Check the scatter
@@ -330,7 +343,7 @@ def test_basegridder_projection_multiple_coordinates():
     npt.assert_allclose(scat.northing, coordinates[1])
 
     # Check the grid
-    grid = grd.grid(region, shape, projection=proj, extra_coords=(13, 17))
+    grid = grd.grid(region=region, shape=shape, projection=proj, extra_coords=(13, 17))
     npt.assert_allclose(grid.scalars.values, data_true)
     npt.assert_allclose(grid.easting.values, coordinates_true[0][0, :])
     npt.assert_allclose(grid.northing.values, coordinates_true[1][:, 0])
@@ -356,6 +369,36 @@ def test_basegridder_projection_multiple_coordinates():
     npt.assert_allclose(prof.distance, distance_true)
 
 
+def test_basegridder_grid_invalid_arguments():
+    """
+    Test if errors and warnings are raised on invalid arguments to grid method
+    """
+    region = (0, 10, -10, -5)
+    angular, linear = 2, 100
+    coordinates = scatter_points(region, 1000, random_state=0, extra_coords=(1, 2))
+    data = angular * coordinates[0] + linear
+    grd = PolyGridder().fit(coordinates, data)
+    # Check error is raised if coordinates and shape are passed
+    grid_coords = (np.linspace(*region[:2], 11), np.linspace(*region[2:], 7))
+    with pytest.raises(ValueError):
+        grd.grid(coordinates=grid_coords, shape=(30, 30))
+    # Check error is raised if coordinates and spacing are passed
+    with pytest.raises(ValueError):
+        grd.grid(coordinates=grid_coords, spacing=10)
+    # Check error is raised if both coordinates and region are passed
+    with pytest.raises(ValueError):
+        grd.grid(coordinates=grid_coords, region=region)
+    # Check if FutureWarning is raised after passing region, spacing or shape
+    with warnings.catch_warnings(record=True) as warns:
+        grd.grid(region=region, shape=(4, 4))
+        assert len(warns) == 1
+        assert issubclass(warns[0].category, FutureWarning)
+    with warnings.catch_warnings(record=True) as warns:
+        grd.grid(region=region, spacing=1)
+        assert len(warns) == 1
+        assert issubclass(warns[0].category, FutureWarning)
+
+
 def test_check_fit_input():
     "Make sure no exceptions are raised for standard cases"
     size = 20
@@ -390,25 +433,18 @@ def test_check_fit_input_fails_weights():
         check_fit_input(coords, (data, data), weights)
 
 
-# Pylint doesn't like X, y scikit-learn argument names.
-# pylint: disable=invalid-name,unused-argument
-
-
 class DummyCrossValidator(BaseBlockCrossValidator):
     """
     Dummy class to test the base cross-validator.
     """
 
-    def _iter_test_indices(self, X=None, y=None, groups=None):
+    def _iter_test_indices(self, X=None, y=None, groups=None):  # noqa: U100,N803
         """
         Yields a list of indices for the entire X.
         """
         yield list(range(X.shape[0]))
 
 
-# pylint: enable=invalid-name,unused-argument
-
-
 def test_baseblockedcrossvalidator_n_splits():
     "Make sure get_n_splits returns the correct value"
     cv = DummyCrossValidator(spacing=1, n_splits=14)
