@@ -11,21 +11,23 @@ from unittest import mock
 
 import numpy as np
 import numpy.testing as npt
-import xarray as xr
-from scipy.spatial import cKDTree  # pylint: disable=no-name-in-module
 import pytest
+import xarray as xr
+from scipy.spatial import cKDTree
 
-from ..coordinates import grid_coordinates
-from ..utils import (
-    parse_engine,
-    dummy_jit,
-    kdtree,
-    grid_to_table,
-    partition_by_sum,
-    make_xarray_grid,
-    meshgrid_to_1d,
-)
 from .. import utils
+from ..coordinates import grid_coordinates, scatter_points
+from ..utils import (
+    dummy_jit,
+    get_ndim_horizontal_coords,
+    grid_to_table,
+    kdtree,
+    make_xarray_grid,
+    meshgrid_from_1d,
+    meshgrid_to_1d,
+    parse_engine,
+    partition_by_sum,
+)
 
 
 def test_parse_engine():
@@ -72,7 +74,7 @@ def test_kdtree():
 def test_grid_to_table_order():
     "Check that coordinates are in the right order when converting to tables"
     lon, lat = grid_coordinates(region=(1, 10, -10, -1), shape=(3, 4))
-    data = lon ** 2
+    data = lon**2
     # If the DataArray is created with coords in an order that doesn't match
     # the dims (which is valid), we were getting it wrong because we were
     # relying on the order of the coords instead of dims. This test would have
@@ -306,3 +308,29 @@ def test_meshgrid_to_1d_invalid():
     northing = np.linspace(-4, -4, 9)
     with pytest.raises(ValueError):
         meshgrid_to_1d((easting, northing))
+
+
+def test_meshgrid_from_1d_invalid():
+    """
+    Check if error is raised after non 1d arrays passed to meshgrid_from_1d
+    """
+    coordinates = grid_coordinates(region=(0, 10, -5, 5), shape=(11, 11))
+    with pytest.raises(ValueError):
+        meshgrid_from_1d(coordinates)
+
+
+def test_check_ndim_easting_northing():
+    """
+    Test if check_ndim_easting_northing works as expected
+    """
+    # Easting and northing as 1d arrays
+    easting, northing = scatter_points((-5, 5, 0, 4), 50, random_state=42)
+    assert get_ndim_horizontal_coords(easting, northing) == 1
+    # Easting and northing as 2d arrays
+    easting, northing = grid_coordinates((-5, 5, 0, 4), spacing=1)
+    assert get_ndim_horizontal_coords(easting, northing) == 2
+    # Check if error is raised after easting and northing with different ndims
+    easting = np.linspace(0, 5, 6)
+    northing = np.linspace(-5, 5, 16).reshape(4, 4)
+    with pytest.raises(ValueError):
+        get_ndim_horizontal_coords(easting, northing)
