@@ -13,12 +13,12 @@ import dask
 import numpy as np
 import pandas as pd
 import xarray as xr
-from scipy.spatial import cKDTree  # pylint: disable=no-name-in-module
+from scipy.spatial import cKDTree
 
 try:
     from pykdtree.kdtree import KDTree as pyKDTree
 except ImportError:
-    pyKDTree = None
+    pyKDTree = None  # noqa: N816
 
 try:
     import numba
@@ -27,9 +27,9 @@ except ImportError:
 
 from .base.utils import (
     check_coordinates,
-    check_extra_coords_names,
     check_data,
     check_data_names,
+    check_extra_coords_names,
     n_1d_arrays,
 )
 
@@ -87,7 +87,7 @@ def parse_engine(engine):
     return engine
 
 
-def dummy_jit(**kwargs):  # pylint: disable=unused-argument
+def dummy_jit(**kwargs):  # noqa: U100
     """
     Replace numba.jit if not installed with a function that raises RunTimeError
 
@@ -110,7 +110,7 @@ def dummy_jit(**kwargs):  # pylint: disable=unused-argument
         "The actual decorator"
 
         @functools.wraps(function)
-        def dummy_function(*args, **kwargs):  # pylint: disable=unused-argument
+        def dummy_function(*args, **kwargs):  # noqa: U100
             "Just raise an exception."
             raise RuntimeError("Could not find numba.")
 
@@ -290,9 +290,9 @@ def make_xarray_grid(
     >>> data = np.ones_like(coordinates[0])
     >>> # Create the grid
     >>> grid = make_xarray_grid(coordinates, data, data_names="dummy")
-    >>> print(grid)
+    >>> print(grid) # doctest: +SKIP
     <xarray.Dataset>
-    Dimensions:   (easting: 3, northing: 2)
+    Dimensions:   (northing: 2, easting: 3)
     Coordinates:
       * easting   (easting) float64 -10.0 -8.0 -6.0
       * northing  (northing) float64 8.0 10.0
@@ -309,9 +309,9 @@ def make_xarray_grid(
     >>> grid = make_xarray_grid(
     ...     coordinates, data, data_names="dummy", extra_coords_names="upward"
     ... )
-    >>> print(grid)
+    >>> print(grid) # doctest: +SKIP
     <xarray.Dataset>
-    Dimensions:   (easting: 3, northing: 2)
+    Dimensions:   (northing: 2, easting: 3)
     Coordinates:
       * easting   (easting) float64 -10.0 -8.0 -6.0
       * northing  (northing) float64 8.0 10.0
@@ -329,7 +329,7 @@ def make_xarray_grid(
     ...     data_names=None,
     ...     extra_coords_names="upward",
     ... )
-    >>> print(grid)
+    >>> print(grid) # doctest: +SKIP
     <xarray.Dataset>
     Dimensions:   (easting: 3, northing: 2)
     Coordinates:
@@ -341,13 +341,7 @@ def make_xarray_grid(
 
     """
     # Check dimensions of the horizontal coordinates of the regular grid
-    ndim = np.ndim(coordinates[0])
-    if ndim != np.ndim(coordinates[1]):
-        raise ValueError(
-            "Incompatible dimensions between horizontal coordinates of the regular grid: "
-            + f"'{ndim}' and '{np.ndim(coordinates[1])}'. "
-            + "Both coordinates must have the same number of dimensions."
-        )
+    ndim = get_ndim_horizontal_coords(*coordinates[:2])
     # Convert 2d horizontal coordinates to 1d arrays if needed
     if ndim == 2:
         coordinates = meshgrid_to_1d(coordinates)
@@ -418,6 +412,92 @@ def meshgrid_to_1d(coordinates):
     return coordinates
 
 
+def meshgrid_from_1d(coordinates):
+    """
+    Convert horizontal coordinates of 2d grids from 1d-arrays to 2d-arrays
+
+    Parameters
+    ----------
+    coordinates : tuple of arrays
+        Arrays with coordinates of each point in the grid. Each array must
+        contain values for a dimension in the order: easting, northing,
+        vertical, etc. The horizontal coordinates (easting and northing) should
+        be 1d arrays, any extra coordinate should be an array with a shape of
+        ``(northing.size, easting.size)``.
+
+    Returns
+    -------
+    coordinates : tuple of arrays
+        Arrays with coordinates of each point in the grid.
+        The horizontal coordinates have been converted to 2d-arrays with the
+        same shape, forming a meshgrid. All extra coordinates have not been
+        modified.
+
+    Examples
+    --------
+
+    >>> easting = np.linspace(0, 4, 5)
+    >>> northing = np.linspace(-3, 3, 7)
+    >>> height = 2 * np.ones((7, 5))
+    >>> coordinates = (easting, northing, height)
+    >>> easting, northing, height = meshgrid_from_1d(coordinates)
+    >>> print(easting)
+    [[0. 1. 2. 3. 4.]
+     [0. 1. 2. 3. 4.]
+     [0. 1. 2. 3. 4.]
+     [0. 1. 2. 3. 4.]
+     [0. 1. 2. 3. 4.]
+     [0. 1. 2. 3. 4.]
+     [0. 1. 2. 3. 4.]]
+    >>> print(northing)
+    [[-3. -3. -3. -3. -3.]
+     [-2. -2. -2. -2. -2.]
+     [-1. -1. -1. -1. -1.]
+     [ 0.  0.  0.  0.  0.]
+     [ 1.  1.  1.  1.  1.]
+     [ 2.  2.  2.  2.  2.]
+     [ 3.  3.  3.  3.  3.]]
+
+    """
+    ndim = get_ndim_horizontal_coords(*coordinates[:2])
+    if ndim != 1:
+        raise ValueError(
+            "Horizontal coordinates must be 1d-arrays. " + f"{ndim}d-arrays provided."
+        )
+    easting, northing = np.meshgrid(coordinates[0], coordinates[1])
+    coordinates = (easting, northing, *coordinates[2:])
+    coordinates = check_coordinates(coordinates)
+    return coordinates
+
+
+def get_ndim_horizontal_coords(easting, northing):
+    """
+    Return the number of dimensions of the horizontal coordinates arrays
+
+    Also check if the two horizontal coordinates arrays same dimensions.
+
+    Parameters
+    ----------
+    easting : nd-array
+        Array for the easting coordinates
+    northing : nd-array
+        Array for the northing coordinates
+
+    Returns
+    -------
+    ndim : int
+        Number of dimensions of the ``easting`` and ``northing`` arrays.
+    """
+    ndim = np.ndim(easting)
+    if ndim != np.ndim(northing):
+        raise ValueError(
+            "Horizontal coordinates dimensions mismatch. "
+            + f"The easting coordinate array has {easting.ndim} dimensions "
+            + f"while the northing has {northing.ndim}."
+        )
+    return ndim
+
+
 def check_meshgrid(coordinates):
     """
     Check if the given horizontal coordinates define a meshgrid
