@@ -12,10 +12,10 @@ import warnings
 import numpy as np
 from sklearn.utils.validation import check_is_fitted
 
-from .base import n_1d_arrays, check_fit_input, least_squares, BaseGridder
+from .base import BaseGridder, check_fit_input, least_squares, n_1d_arrays
+from .coordinates import get_region
 from .spline import warn_weighted_exact_solution
 from .utils import parse_engine
-from .coordinates import get_region
 
 try:
     import numba
@@ -395,15 +395,15 @@ class VectorSpline2D(BaseGridder):
 
 def greens_func_2d(east, north, mindist, poisson):
     "Calculate the Green's functions for the 2D elastic case."
-    distance = np.sqrt(east ** 2 + north ** 2)
+    distance = np.sqrt(east**2 + north**2)
     # The mindist factor helps avoid singular matrices when the force and
     # computation point are too close
     distance += mindist
     # Pre-compute common terms for the Green's functions of each component
     ln_r = (3 - poisson) * np.log(distance)
-    over_r2 = (1 + poisson) / distance ** 2
-    green_ee = ln_r + over_r2 * north ** 2
-    green_nn = ln_r + over_r2 * east ** 2
+    over_r2 = (1 + poisson) / distance**2
+    green_ee = ln_r + over_r2 * north**2
+    green_nn = ln_r + over_r2 * east**2
     green_ne = -over_r2 * east * north
     return green_ee, green_nn, green_ne
 
@@ -449,7 +449,7 @@ def predict_2d_numba(
 ):
     "Calculate the predicted data using numba to speed things up."
     nforces = forces.size // 2
-    for i in numba.prange(east.size):  # pylint: disable=not-an-iterable
+    for i in numba.prange(east.size):
         vec_east[i] = 0
         vec_north[i] = 0
         for j in range(nforces):
@@ -466,7 +466,7 @@ def jacobian_2d_numba(east, north, force_east, force_north, mindist, poisson, ja
     "Calculate the Jacobian matrix using numba to speed things up."
     nforces = force_east.size
     npoints = east.size
-    for i in numba.prange(npoints):  # pylint: disable=not-an-iterable
+    for i in numba.prange(npoints):
         for j in range(nforces):
             green_ee, green_nn, green_ne = GREENS_FUNC_2D_JIT(
                 east[i] - force_east[j], north[i] - force_north[j], mindist, poisson
